package org.jenkinsci.plugins.p4_client.credentials;

import hudson.Extension;
import hudson.Util;

import org.kohsuke.stapler.DataBoundConstructor;

import com.cloudbees.plugins.credentials.CredentialsDescriptor;
import com.cloudbees.plugins.credentials.CredentialsScope;

import edu.umd.cs.findbugs.annotations.CheckForNull;
import edu.umd.cs.findbugs.annotations.NonNull;

public class P4TicketImpl extends P4StandardCredentials {

	/**
	 * Ensure consistent serialisation.
	 */
	private static final long serialVersionUID = 1L;

	@NonNull
	private final String p4port;
	private final boolean ssl;

	@NonNull
	private final String username;

	@NonNull
	private final TicketModeImpl ticket;

	@DataBoundConstructor
	public P4TicketImpl(@CheckForNull CredentialsScope scope,
			@CheckForNull String id, @CheckForNull String description,
			@CheckForNull String p4port, boolean ssl,
			@CheckForNull String username, TicketModeImpl ticket) {

		super(scope, id, description, p4port, ssl, username);
		this.p4port = Util.fixNull(p4port);
		this.ssl = ssl;
		this.username = Util.fixNull(username);
		this.ticket = ticket;

	}

	@NonNull
	public String getP4port() {
		return p4port;
	}

	public boolean isSsl() {
		return ssl;
	}

	@NonNull
	public String getUsername() {
		return username;
	}

	@NonNull
	public String getTicketValue() {
		return ticket.getTicketValue();
	}

	public boolean isTicketValueSet() {
		return ticket.isTicketValueSet();
	}

	@NonNull
	public String getTicketPath() {
		return ticket.getTicketPath();
	}

	public boolean isTicketPathSet() {
		return ticket.isTicketPathSet();
	}

	@Extension
	public static class DescriptorImpl extends CredentialsDescriptor {

		@Override
		public String getDisplayName() {
			return "Perforce Ticket Credentials";
		}

	}
}